﻿
/*
* getHolidayTextUSA
* Function	: holiday.jsから呼ばれる関数。アメリカの祝日の判定する。
* Input		: dtm 判定する日を表すDate Object
* 			: state	祝日に加える州記号、または、Washington D.C.
* Return	: 祝日の場合その日を表す文字列、そうでない場合NULL
* Note		: easter.js が必要
*			: USAおよび州の祝日設定は、基本的には以下のサイトの
*			: Federal holidays, State holidaysとLegal holidayと書かれているものを
*			: ベースにしています。
*			: http://en.wikipedia.org/wiki/Public_holidays_of_the_United_States。
* Update	:2019-01-21 今日が祝日表示にならないバグ修正
*/
function getHolidayTextUSA(dtm, state) {
	var year	= dtm.getFullYear();
	var month	= dtm.getMonth() + 1;
	var daycnt	= dtm.getDate();
	var yo		= dtm.getDay();
	var title	= "";
	
	state = state.toUpperCase();

	// 月の決まらない祝日処理
	// 振り替え休日処理
	// 金曜振り替え休日
	if (yo == 5) {
		var nextDay = getHolidayText(getShiftDay(dtm, 1));
		if (nextDay != "") return "Friday before " + nextDay;
	}
	// 月曜振り替え休日
	if (yo == 1) {
		var beforeDay = getHolidayText(getShiftDay(dtm, -1));
		if (beforeDay != "") return "Monday after " + beforeDay;
	}

	// Good Friday (CT)
	if (("CT,HI,LA,TN,TX".indexOf(state) >= 0) && (yo == 5) && (isEaster(getShiftDay(dtm, 2)))) return "Good Friday (" + state + ")";

	// Mardi gras
	if (("FL,LA,MS".indexOf(state) >= 0) && (yo == 2) && (isEaster(getShiftDay(dtm, 47)))) return "Mardi gras (" + state + ")";

	// 月ごとの祝日処理
	// Federal holiday and U.S. state holiday in Wikipedia
	switch (month) {
		case 1:
			// New Year's Day (USA)
			if (daycnt == 1) return "New Year's Day";
			// Inauguration Day (USA)
			if ((daycnt == 20) && (year % 4 == 1) && (year >= 1965)) return "Inauguration Day";
			// Martin Luther King Day (USA)
			if ((yo == 1) && (daycnt >= 15) && (daycnt <= 21)) return "Birthday of Martin Luther King, Jr.";
			// Lee-Jackson Day (VA)
			if ((state == "VA") && (daycnt >= 11) && (daycnt <= 18)) return "Lee-Jackson Day (VA)";
			if (daycnt == 19) {
				if (state == "ID") {
					// Idaho Human Rights Day (ID)
					return "Idaho Human Rights Day (TX)";
				} else if (state == "NH") {
					// Civil Rights Day (NH)
					return "Civil Rights Day (NH)";
				} else if (state == "TX") {
					// Confederate Heroes Day (TX)
					return "Confederate Heroes Day (TX)";
				} else if ("AL,FL,MS".indexOf(state) >= 0) {
					return "Robert E. Lee's Birthday (" + state + ")";
				}
			}
			// Kansas Day (KA)
			if ((state == "KA") && (daycnt == 29)) return "Kansas Day";
			break;
		case 2:
			// Lincoln's Birthday (CT)
			if (("CT,IL,TN".indexOf(state) >= 0) && (daycnt == 12)) return "Lincoln's Birthday (CT)";
			// President Day (USA)
			if ((yo == 1) && (daycnt >= 15) && (daycnt < 21)) return "Washington's Birthday";
			if ((state == "AR") && (daycnt == 16)) return "Daisy Gatson Bates Day (AR)";
		case 3:
			// Texas Independence Day
			if ((state == "TX") && (daycnt == 2)) return "Texas Independence Day (TX)";
			// Andrew Jackson Day
			if ((state == "TN") && (daycnt == 15)) return "Andrew Jackson Day (TN)";
//			// St.Patrick's Day (USA)
//			if (daycnt == 17) return "St.Patrick's Day";
			// Maryland Day (MD)
			if ((state == "MD") && (daycnt == 25)) return "Maryland Day (MD)";
			// Seward's Day (AK)
			if ((state == "AK") && (daycnt == 27)) return "Seward's Day (AK)";
			// Cesar Chavez Day (Ca)
			if (("CA,CO,TX".indexOf(state) > 0) && (daycnt == 31)) return "César Chávez's birthday ("+state+")";
			// Prince Jonah Kuhio Kalanianaole Day (HI)
			if ((state == "HI") && (daycnt == 26)) return "Prince Jonah Kuhio Kalanianaole Day (HI)";
			
			break;
		case 4:
			// Pascua Florida Day
			if ((state == "FL") && (daycnt == 2)) return "Pascua Florida Day (FL)";
			// Halifax Day
			if ((state == "NC") && (daycnt == 12)) return "Halifax Day (NC)";
			// Patriots' Day (
			if (("ME,MA,TX".indexOf(state) >= 0) && (yo == 1) && (daycnt >= 15) && (daycnt < 22)) return "César Chávez's birthday (" + state + ")";
			// Emancipation Day (Washington D.C.)
			if ((state == "Washington D.C.") && (daycnt == 16)) return "Emancipation Day (Washington D.C.)";
			// anniversary of Battles of Lexington and Concord (MA)
			if (("ME,MA".indexOf(state) >= 0) && (daycnt == 19)) return "anniversary of Battles of Lexington and Concord (" + state + ")";
			// San Jacinto Day (TX)
			if ((state == "TX") && (daycnt == 21)) return "San Jacinto Day (TX)";
			// Confederate Memorial Day (AL:4th Monday, FL:26, GA,MS:Last Monday)
			if ((
				((state == "AL") && (yo == 1) && (daycnt >= 22) && (daycnt <= 28))
			) || (
				((state == "FL") && (daycnt ==26))
			) || (
				(("GA,MS".indexOf(state) >= 0) && (yo == 1) && (daycnt >= 24))
			)) return "Confederate Memorial Day (" + state + ")";
			// Arbor Day (NE)
			if ((state == "NE") && (yo == 5) && (daycnt >= 24)) return "Arbor Day (NE)"
			break;
		case 5:
			// May Day or Lei Day (HI)
			if ((state == "HI") && (daycnt == 1)) return "May Day (HI)";
			// Truman Day;
			if ((state == "MO") && (daycnt == 9)) return "Truman Day (MO)";
			// Confederate Memorial Day
			if ((state == "SC") && (daycnt == 10)) return "Confederate Memorial Day (SC)";
			// Memorial Day (USA)
			if ((yo == 1) && (daycnt >= 25)) return "Memorial Day";
			break;
		case 6:
			// Statehoood Day (TN)
			if ((state == "TN") && (daycnt == 1)) return "Statehoood Day (TN)";
			// Jefferson Davis's Birthday
			if ((
				((state == "AL") && (yo == 1) && (daycnt <= 7))
			) || (
				((state == "FL") && (daycnt == 3))
			)) return "Jefferson Davis's Birthday (" + state + ")"
			// Kamehameha Day (HI)
			if ((state == "HI") && (daycnt == 11)) return "Kamehameha Day (HI)";
//			// Flag Day
//			if (daycnt == 14) return "Flag Day";
			// Emancipation Day in Texas
			if ((state == "TX") && (daycnt == 19)) return "Emancipation Day in Texas (TX)";
			// West Virginia Day (WV)
			if ((state == "WV") && (daycnt == 20)) return "West Virginia Day (WV)";
			break;
		case 7:
			// Independence Day (USA)
			if (daycnt == 4) return "Independence Day";
			// Pioneer Day (UT)
			if ((state == "UT") && (daycnt == 24)) return "Pioneer Day (UT)";
			break;
		case 8:
			// Colorado Day (CO)
			if ((state == "CO") && (daycnt == 1)) return "Colorado Day (CO)";
			// Victory over Japan Day (RI)
			if ((state == "RI") && (daycnt >= 8) && (daycnt <=14)) return "V.J. Day (RI)";
			
			// Admission Day or Statehood Day (HI)
			if ((state == "HI") && (daycnt >= 15) && (daycnt <=21)) return "Admission Day (HI)";
			// Lyndon Baines Johnson Day (TX)
			if ((state == "TX") && (daycnt == 27)) return "Lyndon Baines Johnson Day (TX)";
			
			break;
		case 9:
			// Labor Day (USA)
			if ((yo == 1) && (daycnt <= 7)) return "Labor Day";
			// Admission Day (Ca)
			if ((state == "CA") && (daycnt == 9)) return "Admission Day (Ca)";
			break;
		case 10:
			// Columbus Day (USA), Native American Day (CA, SD)
			if ((yo == 1) && (daycnt >= 8) && (daycnt <= 14)) {
				if ("CA,SD".indexOf(state) >= 0) {
					return "Native American Day (" + state + ")";
				} else {
					return "Columbus Day";
				}
			}
			// Alaska Day (AK)
			if ((state == "AK") && (daycnt == 18)) return "Alaska Day (AK)";
			// Nevada Day (NV)
			if ((state == "NV") && (daycnt == 31)) return "Nevada Day (NV)";
//			// Halloween
//			if (daycnt == 31) return "Halloween";
			break;
		case 11:
			// Veteran's Day (USA)
			if (daycnt == 11) return "Veterans Day";
			// Statehood Day (OK)
			if ((state == "OK") && (daycnt == 16)) return "Statehood Day (OK)";
			
			// Thanksgiving Day (USA)
			if ((yo == 4) && (daycnt >= 22) && (daycnt < 29)) return "Thanksgiving Day";
			break;
		case 12:
			// Christmas (USA)
			if (daycnt == 25) return "Christmas Day";
			break;
	}
	return title;
}

